@@ -9,16 +9,18 @@ or system-wide repository of plugins.
 """
 
 __author__ = "Brian Connelly <bdc@msu.edu>"
-__version__ = "1.0.7"
+__version__ = "1.0.8"
 __credits__ = "Brian Connelly"
 
 import seeds as S
+from seeds.SEEDSError import *
 from optparse import OptionParser
 
 import os
 import re
 import sys
 
+
 class ProgressBar:
     def __init__(self, min_value = 0, max_value = 0, width=60):
         self.bar = ''
@@ -63,19 +65,17 @@ class ProgressBar:
 
 
 def main():
-
     parser = OptionParser('usage: %prog [options] arg')
     parser.add_option("-c", "--config", dest="configfile", type="string", default="seeds.cfg",
                       help="read config file (default: seeds.cfg)")
     parser.add_option("-C", "--genconfig", action="store_true", dest="genconfig", help="write config file used (experiment.cfg)")
-    parser.add_option("-d", "--data_dir", dest="datadir", type="string", default="data",
+    parser.add_option("-d", "--data_dir", dest="datadir", type="string",
                       help="write data to this directory (default: data)")
+    parser.add_option("-e", "--experiment", dest="experiment", type="string", help="label of the experiment to run")
     parser.add_option("-p", "--param", dest="params", type="string", help="Set config values.  Semicolon-separated list of section.param=val")
     parser.add_option("-q", "--quiet", action="store_true", dest="quiet", help="suppress all output messages")
-    parser.add_option("-r", "--resume", dest="snapfile", type="string", help="resume experiment from the provided snapshot file")
     parser.add_option("-s", "--seed", dest="seed", type=int, default=0,
                       help="set random seed (default: use clock)")
-    parser.add_option("-S", "--snapshot", action="store_true", dest="snapshot", help="write snapshot file at end of experiment")
     parser.add_option("-v", "--version", action="store_true", dest="version", help="display version information and quit")
 
     (cmd_options, cmd_args) = parser.parse_args()
@@ -89,18 +89,21 @@ def main():
         print "%s (SEEDS Version %s)" % (__version__, S.__version__)
         sys.exit(0)
 
-    # Create the world...
-    # TODO: what if data_dir is set in config file?
-    world = S.World(configfile=cmd_options.configfile, seed=random_seed)
-    world.config.set('Experiment', 'data_dir', cmd_options.datadir)
+    if cmd_options.experiment:
+        experiment_label = cmd_options.experiment
+    else:
+        experiment_label = None
 
+    # Create the Experiment...
+    try:
+        experiment = S.Experiment(configfile=cmd_options.configfile, seed=random_seed,
+                                  label=experiment_label)
+    except SEEDSError as err:
+        print "Error:", err
+        sys.exit(1)
 
-    # Load the state of the world from a snapshot
-    if cmd_options.snapfile:
-        if not os.path.exists(cmd_options.snapfile):
-            print "Error: Snapshot file does not exist"
-            sys.exit(1)
-        world.load_snapshot(cmd_options.snapfile)
+    if cmd_options.datadir:
+        experiment.config.set(experiment.config_section, 'data_dir', cmd_options.datadir)
 
 
     # Add command-line config options
@@ -110,17 +113,14 @@ def main():
             # This is perhaps not the best regexp for comma-separated lists as values... need spaces.
             m = re.match(r"(?P<section>[A-Za-z0-9:_]+)\.(?P<parameter>[A-Za-z0-9:_]+)\s*=\s*(?P<value>-?[A-Za-z0-9_\.\,]+)", opt)
             if m != None:
-                #print "Setting [%s]%s=%s" % (m.group("section"), m.group("parameter"), m.group("value"))
-                world.config.set(m.group("section"), m.group("parameter"), m.group("value"))
+                experiment.config.set(m.group("section"), m.group("parameter"), m.group("value"))
             else:
                 print "Error: Could not parse parameter setting", opt
 
-
     # Get the current configured list of plugin directories
-    cfg_plugindirs = world.config.get(section="Experiment", name="plugin_dirs",
-                                      default="")
-    if len(cfg_plugindirs) > 0:
-        plugindirs = world.config.get(section="Experiment", name="plugin_dirs").split(",")
+    cfg_plugindirs = experiment.config.get(section="Experiment", name="plugin_dirs")
+    if cfg_plugindirs:
+        plugindirs = experiment.config.get(section="Experiment", name="plugin_dirs").split(",")
     else:
         plugindirs = []
 
@@ -133,29 +133,32 @@ def main():
 
     if len(plugindirs) > 0:
         pdirs = ",".join(plugindirs)
-        world.config.set(section="Experiment", name="plugin_dirs", value=pdirs)
+        experiment.config.set(section="Experiment", name="plugin_dirs", value=pdirs)
 
-    # Do the experiment...
-    prog = ProgressBar(0, world.config.getint('Experiment', 'epochs'))
+    if not cmd_options.quiet:
+        print "Experiment ID:", experiment.uuid
+
+    # Set up a progress bar
+    prog = ProgressBar(0, experiment.config.getint(experiment.config_section, 'epochs'))
     oldprog = str(prog)
 
-    while world.proceed:
-        prog.update_amount(world.epoch)
-        if not cmd_options.quiet and oldprog != str(prog):
-            print prog, "\r",
-            sys.stdout.flush()
-            oldprog=str(prog)
-
-        world.update()
+    # Do the experiment...
+    try:
+        for epoch in experiment:
+            prog.update_amount(epoch)
+            if not cmd_options.quiet and oldprog != str(prog):
+                print prog, "\r",
+                sys.stdout.flush()
+                oldprog=str(prog)
+    except SEEDSError as err:
+        print "Error:", err
+        sys.exit(2)
+    else:
+        experiment.teardown()
 
     # Write a config file
     if cmd_options.genconfig:
-        world.config.write(filename='experiment.cfg')
-
-    # Write a snapshot at the end
-    if cmd_options.snapshot:
-        snap = world.get_snapshot()
-        snap.write()
+        experiment.config.write(filename='experiment.cfg')
 
     if not cmd_options.quiet:
         print
