@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-VERSION = (1, 0, 7)
+VERSION = (1, 0, 8)
 __version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
 __license__ = "Apache Version 2"
 __download_url__ = "https://github.com/downloads/briandconnelly/seeds/seeds-%s.tar.gz" % (__version__)
@@ -7,9 +7,11 @@ __download_url__ = "https://github.com/downloads/briandconnelly/seeds/seeds-%s.t
 from seeds.Action import *
 from seeds.Cell import *
 from seeds.Config import *
+from seeds.Experiment import *
 from seeds.PluginManager import *
+from seeds.Population import *
 from seeds.Resource import *
+from seeds.ResourceCell import *
+from seeds.SEEDSError import *
 from seeds.Topology import *
-from seeds.TopologyManager import *
-from seeds.World import *
 
